==> dpuser_4.0+dfsg.orig.tar.xz: dpusersrc/QFitsView/extra/tetrixpiece.cpp <==
/****************************************************************************
 **
 ** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the documentation of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
** License versions 2.0 or 3.0 as published by the Free Software
** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file.  Alternatively you may (at
** your option) use any later version of the GNU General Public
** License if such license has been publicly approved by Trolltech ASA
** (or its successors, if any) and the KDE Free Qt Foundation. In
** addition, as a special exception, Trolltech gives you certain
** additional rights. These rights are described in the Trolltech GPL
** Exception version 1.2, which can be found at
** http://www.trolltech.com/products/qt/gplexception/ and in the file
** GPL_EXCEPTION.txt in this package.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
** you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** In addition, as a special exception, Trolltech, as the sole
** copyright holder for Qt Designer, grants users of the Qt/Eclipse
** Integration plug-in the right for the Qt/Eclipse Integration to
** link to functionality provided by Qt Designer and its related
** libraries.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ****************************************************************************/

 #include <QtCore>

 #include <stdlib.h>

 #include "tetrixpiece.h"

 void TetrixPiece::setRandomShape()
 {
     setShape(TetrixShape(qrand() % 7 + 1));
 }

 void TetrixPiece::setShape(TetrixShape shape)
 {
     static const int coordsTable[8][4][2] = {
         { { 0, 0 },   { 0, 0 },   { 0, 0 },   { 0, 0 } },
         { { 0, -1 },  { 0, 0 },   { -1, 0 },  { -1, 1 } },
         { { 0, -1 },  { 0, 0 },   { 1, 0 },   { 1, 1 } },
         { { 0, -1 },  { 0, 0 },   { 0, 1 },   { 0, 2 } },
         { { -1, 0 },  { 0, 0 },   { 1, 0 },   { 0, 1 } },
         { { 0, 0 },   { 1, 0 },   { 0, 1 },   { 1, 1 } },
         { { -1, -1 }, { 0, -1 },  { 0, 0 },   { 0, 1 } },
         { { 1, -1 },  { 0, -1 },  { 0, 0 },   { 0, 1 } }
     };

     for (int i = 0; i < 4 ; i++) {
         for (int j = 0; j < 2; ++j)
             coords[i][j] = coordsTable[shape][i][j];
     }
     pieceShape = shape;
 }

 int TetrixPiece::minX() const
 {
     int min = coords[0][0];
     for (int i = 1; i < 4; ++i)
         min = qMin(min, coords[i][0]);
     return min;
 }

 int TetrixPiece::maxX() const
 {
     int max = coords[0][0];
     for (int i = 1; i < 4; ++i)
         max = qMax(max, coords[i][0]);
     return max;
 }

 int TetrixPiece::minY() const
 {
     int min = coords[0][1];
     for (int i = 1; i < 4; ++i)
         min = qMin(min, coords[i][1]);
     return min;
 }

 int TetrixPiece::maxY() const
 {
     int max = coords[0][1];
     for (int i = 1; i < 4; ++i)
         max = qMax(max, coords[i][1]);
     return max;
 }

 TetrixPiece TetrixPiece::rotatedLeft() const
 {
     if (pieceShape == SquareShape)
         return *this;

     TetrixPiece result;
     result.pieceShape = pieceShape;
     for (int i = 0; i < 4; ++i) {
         result.setX(i, y(i));
         result.setY(i, -x(i));
     }
     return result;
 }

 TetrixPiece TetrixPiece::rotatedRight() const
 {
     if (pieceShape == SquareShape)
         return *this;

     TetrixPiece result;
     result.pieceShape = pieceShape;
     for (int i = 0; i < 4; ++i) {
         result.setX(i, -y(i));
         result.setY(i, x(i));
     }
     return result;
 }

==> dpuser_4.1+dfsg.orig.tar.xz: dpusersrc/QFitsView/extra/tetrixpiece.cpp <==
/****************************************************************************
 **
 ** Copyright (C) 2004-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the documentation of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
** License versions 2.0 or 3.0 as published by the Free Software
** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file.  Alternatively you may (at
** your option) use any later version of the GNU General Public
** License if such license has been publicly approved by Trolltech ASA
** (or its successors, if any) and the KDE Free Qt Foundation. In
** addition, as a special exception, Trolltech gives you certain
** additional rights. These rights are described in the Trolltech GPL
** Exception version 1.2, which can be found at
** http://www.trolltech.com/products/qt/gplexception/ and in the file
** GPL_EXCEPTION.txt in this package.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
** you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** In addition, as a special exception, Trolltech, as the sole
** copyright holder for Qt Designer, grants users of the Qt/Eclipse
** Integration plug-in the right for the Qt/Eclipse Integration to
** link to functionality provided by Qt Designer and its related
** libraries.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 **
 ****************************************************************************/

 #include <QtCore>

 #include <stdlib.h>

 #include "tetrixpiece.h"

 void TetrixPiece::setRandomShape()
 {
     setShape(TetrixShape(rand() % 7 + 1));
 }

 void TetrixPiece::setShape(TetrixShape shape)
 {
     static const int coordsTable[8][4][2] = {
         { { 0, 0 },   { 0, 0 },   { 0, 0 },   { 0, 0 } },
         { { 0, -1 },  { 0, 0 },   { -1, 0 },  { -1, 1 } },
         { { 0, -1 },  { 0, 0 },   { 1, 0 },   { 1, 1 } },
         { { 0, -1 },  { 0, 0 },   { 0, 1 },   { 0, 2 } },
         { { -1, 0 },  { 0, 0 },   { 1, 0 },   { 0, 1 } },
         { { 0, 0 },   { 1, 0 },   { 0, 1 },   { 1, 1 } },
         { { -1, -1 }, { 0, -1 },  { 0, 0 },   { 0, 1 } },
         { { 1, -1 },  { 0, -1 },  { 0, 0 },   { 0, 1 } }
     };

     for (int i = 0; i < 4 ; i++) {
         for (int j = 0; j < 2; ++j)
             coords[i][j] = coordsTable[shape][i][j];
     }
     pieceShape = shape;
 }

 int TetrixPiece::minX() const
 {
     int min = coords[0][0];
     for (int i = 1; i < 4; ++i)
         min = qMin(min, coords[i][0]);
     return min;
 }

 int TetrixPiece::maxX() const
 {
     int max = coords[0][0];
     for (int i = 1; i < 4; ++i)
         max = qMax(max, coords[i][0]);
     return max;
 }

 int TetrixPiece::minY() const
 {
     int min = coords[0][1];
     for (int i = 1; i < 4; ++i)
         min = qMin(min, coords[i][1]);
     return min;
 }

 int TetrixPiece::maxY() const
 {
     int max = coords[0][1];
     for (int i = 1; i < 4; ++i)
         max = qMax(max, coords[i][1]);
     return max;
 }

 TetrixPiece TetrixPiece::rotatedLeft() const
 {
     if (pieceShape == SquareShape)
         return *this;

     TetrixPiece result;
     result.pieceShape = pieceShape;
     for (int i = 0; i < 4; ++i) {
         result.setX(i, y(i));
         result.setY(i, -x(i));
     }
     return result;
 }

 TetrixPiece TetrixPiece::rotatedRight() const
 {
     if (pieceShape == SquareShape)
         return *this;

     TetrixPiece result;
     result.pieceShape = pieceShape;
     for (int i = 0; i < 4; ++i) {
         result.setX(i, -y(i));
         result.setY(i, x(i));
     }
     return result;
 }
